@@ -318,6 +318,6 @@ mod run_interface {
 #[test]
 fn memory_test() {
     use cradle::prelude::*;
-    cmd_unit!(%"cargo build -p memory-test --release");
-    cmd_unit!(%"cargo run -p memory-test --bin run_test");
+    cmd_unit!(%"cargo build -p memory-tests --release");
+    cmd_unit!(%"cargo run -p memory-tests --bin run");
 }
